@@ -3,6 +3,7 @@
 aembit_raw_output_chain_name=aembit_raw_output_chain
 aembit_nat_output_chain_name=aembit_nat_output_chain
 aembit_nat_prerouting_chain_name=aembit_nat_prerouting_chain
+aembit_filter_input_chain_name=aembit_filter_input_chain
 
 aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
@@ -104,6 +105,25 @@ fi
 # Add chain
 iptables -t nat -A PREROUTING -j "${aembit_nat_prerouting_chain_name}"
 
+# ----- aembit_filter_input_chain ------
+
+# Create chain
+iptables -t filter -N "${aembit_filter_input_chain_name}"
+
+# Allow local traffic to be sent to the Agent Proxy traffic port.
+iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp --dport "${agent_proxy_port}" -i lo -j ACCEPT
+
+# Allow traffic from local containers to be sent to the Agent proxy traffic port.
+if [ -n "$container_cidr" ]; then
+    iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp -s  $container_cidr --dport "${agent_proxy_port}" -j ACCEPT
+fi
+
+# Disallow the rest of the traffic (coming from external interfaces) to be sent to the Agent Proxy traffic port.
+iptables -t filter -A "${aembit_filter_input_chain_name}" -p tcp --dport "${agent_proxy_port}" -j REJECT
+
+# Add chain
+iptables -t filter -A INPUT -j "${aembit_filter_input_chain_name}"
+
 # ------ Non custom chains ------
 
 # https://learn.microsoft.com/en-us/azure/virtual-network/what-is-ip-address-168-63-129-16
